==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/inputs/PreReleaseAccessRequestSpecArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.inputs

import com.pulumi.azurenative.testbase.inputs.PreReleaseAccessRequestSpecArgs.builder
import com.pulumi.azurenative.testbase.kotlin.enums.Engagements
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property city
 * @property companyWebsite
 * @property countryAndRegion
 * @property email
 * @property engagements
 * @property organizationName
 * @property stateOrProvince
 * @property streetAddress
 * @property zipCode
 */
public data class PreReleaseAccessRequestSpecArgs(
    public val city: Output<String>? = null,
    public val companyWebsite: Output<String>? = null,
    public val countryAndRegion: Output<String>? = null,
    public val email: Output<String>? = null,
    public val engagements: Output<List<Either<String, Engagements>>>? = null,
    public val organizationName: Output<String>? = null,
    public val stateOrProvince: Output<String>? = null,
    public val streetAddress: Output<String>? = null,
    public val zipCode: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.testbase.inputs.PreReleaseAccessRequestSpecArgs> {
    override fun toJava(): com.pulumi.azurenative.testbase.inputs.PreReleaseAccessRequestSpecArgs =
        com.pulumi.azurenative.testbase.inputs.PreReleaseAccessRequestSpecArgs.builder()
            .city(city?.applyValue({ args0 -> args0 }))
            .companyWebsite(companyWebsite?.applyValue({ args0 -> args0 }))
            .countryAndRegion(countryAndRegion?.applyValue({ args0 -> args0 }))
            .email(email?.applyValue({ args0 -> args0 }))
            .engagements(
                engagements?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .organizationName(organizationName?.applyValue({ args0 -> args0 }))
            .stateOrProvince(stateOrProvince?.applyValue({ args0 -> args0 }))
            .streetAddress(streetAddress?.applyValue({ args0 -> args0 }))
            .zipCode(zipCode?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PreReleaseAccessRequestSpecArgs].
 */
@PulumiTagMarker
public class PreReleaseAccessRequestSpecArgsBuilder internal constructor() {
    private var city: Output<String>? = null

    private var companyWebsite: Output<String>? = null

    private var countryAndRegion: Output<String>? = null

    private var email: Output<String>? = null

    private var engagements: Output<List<Either<String, Engagements>>>? = null

    private var organizationName: Output<String>? = null

    private var stateOrProvince: Output<String>? = null

    private var streetAddress: Output<String>? = null

    private var zipCode: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ynoxgisybqrsyshj")
    public suspend fun city(`value`: Output<String>) {
        this.city = value
    }

    /**
     * @param value
     */
    @JvmName("nhvnbafnpuxsqdnl")
    public suspend fun companyWebsite(`value`: Output<String>) {
        this.companyWebsite = value
    }

    /**
     * @param value
     */
    @JvmName("jsvwbphhkmnwugcf")
    public suspend fun countryAndRegion(`value`: Output<String>) {
        this.countryAndRegion = value
    }

    /**
     * @param value
     */
    @JvmName("rcclxlqrsnodmome")
    public suspend fun email(`value`: Output<String>) {
        this.email = value
    }

    /**
     * @param value
     */
    @JvmName("jgmmhryxhddhcirf")
    public suspend fun engagements(`value`: Output<List<Either<String, Engagements>>>) {
        this.engagements = value
    }

    @JvmName("bpomqmcejyqwwqqg")
    public suspend fun engagements(vararg values: Output<Either<String, Engagements>>) {
        this.engagements = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("kbrbhqftelvikhub")
    public suspend fun engagements(values: List<Output<Either<String, Engagements>>>) {
        this.engagements = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("xjqomxvttpahibha")
    public suspend fun organizationName(`value`: Output<String>) {
        this.organizationName = value
    }

    /**
     * @param value
     */
    @JvmName("aelffmkpigjfljgw")
    public suspend fun stateOrProvince(`value`: Output<String>) {
        this.stateOrProvince = value
    }

    /**
     * @param value
     */
    @JvmName("oeyxkolmayyttvtv")
    public suspend fun streetAddress(`value`: Output<String>) {
        this.streetAddress = value
    }

    /**
     * @param value
     */
    @JvmName("slceybgmpeymikoj")
    public suspend fun zipCode(`value`: Output<String>) {
        this.zipCode = value
    }

    /**
     * @param value
     */
    @JvmName("fttkmidrgdljrisc")
    public suspend fun city(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.city = mapped
    }

    /**
     * @param value
     */
    @JvmName("lfdjsaddbpmvgcdf")
    public suspend fun companyWebsite(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.companyWebsite = mapped
    }

    /**
     * @param value
     */
    @JvmName("cuuqfdlthptqcjkk")
    public suspend fun countryAndRegion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.countryAndRegion = mapped
    }

    /**
     * @param value
     */
    @JvmName("jekmgivqebwrpgjt")
    public suspend fun email(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.email = mapped
    }

    /**
     * @param value
     */
    @JvmName("akupkbmjgobueunk")
    public suspend fun engagements(`value`: List<Either<String, Engagements>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.engagements = mapped
    }

    /**
     * @param values
     */
    @JvmName("rnhuyirsksijewvr")
    public suspend fun engagements(vararg values: Either<String, Engagements>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.engagements = mapped
    }

    /**
     * @param value
     */
    @JvmName("iblmoikpuqyghqvq")
    public suspend fun organizationName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.organizationName = mapped
    }

    /**
     * @param value
     */
    @JvmName("ygmtmneumieigkcr")
    public suspend fun stateOrProvince(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stateOrProvince = mapped
    }

    /**
     * @param value
     */
    @JvmName("aihkvqgtxxrckcyo")
    public suspend fun streetAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.streetAddress = mapped
    }

    /**
     * @param value
     */
    @JvmName("fpcduafcaigxtfha")
    public suspend fun zipCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zipCode = mapped
    }

    internal fun build(): PreReleaseAccessRequestSpecArgs = PreReleaseAccessRequestSpecArgs(
        city = city,
        companyWebsite = companyWebsite,
        countryAndRegion = countryAndRegion,
        email = email,
        engagements = engagements,
        organizationName = organizationName,
        stateOrProvince = stateOrProvince,
        streetAddress = streetAddress,
        zipCode = zipCode,
    )
}

==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/inputs/PreReleaseAccessRequestSpecArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.inputs

import com.pulumi.azurenative.testbase.inputs.PreReleaseAccessRequestSpecArgs.builder
import com.pulumi.azurenative.testbase.kotlin.enums.Engagements
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property city
 * @property companyWebsite
 * @property countryAndRegion
 * @property email
 * @property engagements
 * @property organizationName
 * @property stateOrProvince
 * @property streetAddress
 * @property zipCode
 */
public data class PreReleaseAccessRequestSpecArgs(
    public val city: Output<String>? = null,
    public val companyWebsite: Output<String>? = null,
    public val countryAndRegion: Output<String>? = null,
    public val email: Output<String>? = null,
    public val engagements: Output<List<Either<String, Engagements>>>? = null,
    public val organizationName: Output<String>? = null,
    public val stateOrProvince: Output<String>? = null,
    public val streetAddress: Output<String>? = null,
    public val zipCode: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.testbase.inputs.PreReleaseAccessRequestSpecArgs> {
    override fun toJava(): com.pulumi.azurenative.testbase.inputs.PreReleaseAccessRequestSpecArgs =
        com.pulumi.azurenative.testbase.inputs.PreReleaseAccessRequestSpecArgs.builder()
            .city(city?.applyValue({ args0 -> args0 }))
            .companyWebsite(companyWebsite?.applyValue({ args0 -> args0 }))
            .countryAndRegion(countryAndRegion?.applyValue({ args0 -> args0 }))
            .email(email?.applyValue({ args0 -> args0 }))
            .engagements(
                engagements?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .organizationName(organizationName?.applyValue({ args0 -> args0 }))
            .stateOrProvince(stateOrProvince?.applyValue({ args0 -> args0 }))
            .streetAddress(streetAddress?.applyValue({ args0 -> args0 }))
            .zipCode(zipCode?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PreReleaseAccessRequestSpecArgs].
 */
@PulumiTagMarker
public class PreReleaseAccessRequestSpecArgsBuilder internal constructor() {
    private var city: Output<String>? = null

    private var companyWebsite: Output<String>? = null

    private var countryAndRegion: Output<String>? = null

    private var email: Output<String>? = null

    private var engagements: Output<List<Either<String, Engagements>>>? = null

    private var organizationName: Output<String>? = null

    private var stateOrProvince: Output<String>? = null

    private var streetAddress: Output<String>? = null

    private var zipCode: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("vaossutcbymakqlf")
    public suspend fun city(`value`: Output<String>) {
        this.city = value
    }

    /**
     * @param value
     */
    @JvmName("igoaaumlcusxdtgw")
    public suspend fun companyWebsite(`value`: Output<String>) {
        this.companyWebsite = value
    }

    /**
     * @param value
     */
    @JvmName("hrfjxltguviggnui")
    public suspend fun countryAndRegion(`value`: Output<String>) {
        this.countryAndRegion = value
    }

    /**
     * @param value
     */
    @JvmName("wxsphugigiavwssl")
    public suspend fun email(`value`: Output<String>) {
        this.email = value
    }

    /**
     * @param value
     */
    @JvmName("dyxjjyawiprfpask")
    public suspend fun engagements(`value`: Output<List<Either<String, Engagements>>>) {
        this.engagements = value
    }

    @JvmName("bfqvgqtluvdwlmbq")
    public suspend fun engagements(vararg values: Output<Either<String, Engagements>>) {
        this.engagements = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("qubytolvdygmufhk")
    public suspend fun engagements(values: List<Output<Either<String, Engagements>>>) {
        this.engagements = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("crhcklqrdaratjua")
    public suspend fun organizationName(`value`: Output<String>) {
        this.organizationName = value
    }

    /**
     * @param value
     */
    @JvmName("jirygricvuknfyil")
    public suspend fun stateOrProvince(`value`: Output<String>) {
        this.stateOrProvince = value
    }

    /**
     * @param value
     */
    @JvmName("swaispqfnqqlwrgy")
    public suspend fun streetAddress(`value`: Output<String>) {
        this.streetAddress = value
    }

    /**
     * @param value
     */
    @JvmName("lyrhcywfrvumblqm")
    public suspend fun zipCode(`value`: Output<String>) {
        this.zipCode = value
    }

    /**
     * @param value
     */
    @JvmName("vtwqvedgxhnbxnkj")
    public suspend fun city(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.city = mapped
    }

    /**
     * @param value
     */
    @JvmName("ksmkkesjabejnufa")
    public suspend fun companyWebsite(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.companyWebsite = mapped
    }

    /**
     * @param value
     */
    @JvmName("cafqsicoqrxgjmhd")
    public suspend fun countryAndRegion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.countryAndRegion = mapped
    }

    /**
     * @param value
     */
    @JvmName("qpvrbgqnnpxjhdws")
    public suspend fun email(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.email = mapped
    }

    /**
     * @param value
     */
    @JvmName("mwqgdupcwyodkmhw")
    public suspend fun engagements(`value`: List<Either<String, Engagements>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.engagements = mapped
    }

    /**
     * @param values
     */
    @JvmName("iuddkuqbociegksn")
    public suspend fun engagements(vararg values: Either<String, Engagements>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.engagements = mapped
    }

    /**
     * @param value
     */
    @JvmName("fqcepkrqujdurwmo")
    public suspend fun organizationName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.organizationName = mapped
    }

    /**
     * @param value
     */
    @JvmName("hopiupmmwopjsgud")
    public suspend fun stateOrProvince(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stateOrProvince = mapped
    }

    /**
     * @param value
     */
    @JvmName("gewabmvrkyjpwyhx")
    public suspend fun streetAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.streetAddress = mapped
    }

    /**
     * @param value
     */
    @JvmName("hryuftaybejdsdbx")
    public suspend fun zipCode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zipCode = mapped
    }

    internal fun build(): PreReleaseAccessRequestSpecArgs = PreReleaseAccessRequestSpecArgs(
        city = city,
        companyWebsite = companyWebsite,
        countryAndRegion = countryAndRegion,
        email = email,
        engagements = engagements,
        organizationName = organizationName,
        stateOrProvince = stateOrProvince,
        streetAddress = streetAddress,
        zipCode = zipCode,
    )
}
